/*
 * Copyright 1999-2000, University of Notre Dame.
 * Authors: Jeffrey M. Squyres and Dale Southard
 * 
 * This file is part of the Notre Dame Password Storage and Retrieval
 * (PSR) system.
 * 
 * You should have received a copy of the License Agreement for the Notre
 * Dame PSR system along with the software; see the file LICENSE.  If
 * not, contact Office of Research, University of Notre Dame, Notre Dame,
 * IN 46556.
 * 
 * Permission to modify the code and to distribute modified code is
 * granted, provided the text of this NOTICE is retained, a notice that
 * the code was modified is included with the above COPYRIGHT NOTICE and
 * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
 * file is distributed with the modified code.
 * 
 * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
 * By way of example, but not limitation, Licensor MAKES NO
 * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
 * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
 * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
 * OR OTHER RIGHTS.
 * 
 * Additional copyrights may follow.
 * 
 *
 * $Id: afsauth.c,v 1.4 2000/11/14 15:40:59 jsquyres Exp $
 * 
 * Provides routines necessary for authenticating into AFS.
 * 
 * Authenticate (const char *ln, const char *pw) Does the actual
 * authentication.  It takes pointers to strings with the desired AFS
 * login name and AFS password.  Returns 0 on success.
 * 
 * AuthLife (void) Calculates the life of the token to the hour (rounds
 * down) and returns it as an int.  Returns -1 on failure.
 * 
 */


#include <afs/param.h>
#include <afs/auth.h>
#include <afs/kautils.h>
#include <stdlib.h>

#include "psr.h"


/* The Authenticate routine.  For AFS we just call the correct routine
   and discard any information we don't want.  Return 0 on success. */

int 
Authenticate(char *ln, char *pw)
{
  int32 expires = -1;

  char *reason;

  int lifetime = 0;

  int spare2 = 0;


  if (ka_UserAuthenticateGeneral(KA_USERAUTH_VERSION,
  ln, (char *) 0, (char *) 0, pw, lifetime, &expires, spare2, &reason)) {
    (void) fprintf(stderr,
		   "AFS authentication failed because: %s\n", reason);
    return (1);
  }
  return (0);
}


/* The auth_life routine.  For AFS, we get our token lifetime and covert it
   to hours. Returns the token life in hours or -1 on fail. */

int 
AuthLife(void)
{
  int life_hours, cell_number = 0;

  struct ktc_principal service_name, client_name;

  struct ktc_token current_token;


  if (ktc_ListTokens(cell_number, &cell_number, &service_name)) {
    (void) fprintf(stderr,
		   "Couldn't find current token\n");
    return (-1);
  } else if (ktc_GetToken(&service_name, &current_token,
			  sizeof(current_token), &client_name)) {
    (void) fprintf(stderr,
		   "Couldn't get info about current token\n");
    return (-1);
  }
  life_hours = (current_token.endTime - time(NULL)) / 3600;
  return (life_hours);
}


/* GetNewPAG() -- gets a new PAG */

void 
GetNewPAG()
{
  setpag();
}
