/*
 * Copyright 1999-2000, University of Notre Dame.
 * Authors: Jeffrey M. Squyres and Dale Southard
 * 
 * This file is part of the Notre Dame Password Storage and Retrieval
 * (PSR) system.
 * 
 * You should have received a copy of the License Agreement for the Notre
 * Dame PSR system along with the software; see the file LICENSE.  If
 * not, contact Office of Research, University of Notre Dame, Notre Dame,
 * IN 46556.
 * 
 * Permission to modify the code and to distribute modified code is
 * granted, provided the text of this NOTICE is retained, a notice that
 * the code was modified is included with the above COPYRIGHT NOTICE and
 * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
 * file is distributed with the modified code.
 * 
 * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
 * By way of example, but not limitation, Licensor MAKES NO
 * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
 * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
 * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
 * OR OTHER RIGHTS.
 * 
 * Additional copyrights may follow.
 * 
 *
 * $Id: files.c,v 1.5 2000/11/14 15:41:00 jsquyres Exp $
 *
 * Provides routines for locating/accessing pbs_authr files.
 *
 */

#include <limits.h>
#include <pwd.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <global.h>
#include <rsaref.h>

#include "psr.h"

/* LocateEPassFile() -- takes pointers with the epass filename
(which is assumed to be at least PATH_MAX)  desired login
name and keyname as arugements.  On return, epass  points to a string
containing the absolute pathname of the users encrypted password for that zone.
Returns 0 on success, 1 on fail */

int 
DefaultEPassFile(char *filename, const char *logname, const char *keyname)
{
  struct passwd *pw_entry;

  pw_entry = getpwnam(logname);
  if (pw_entry == NULL)
    return (1);
  if (strlen(pw_entry->pw_dir) + sizeof(PATHSEP)
      + sizeof(DAHOMED) + sizeof(PATHSEP) + strlen(keyname)
      + sizeof(EPASSSUFFIX) + 1 > PATH_MAX)
    return (1);
  if (strcpy(filename, pw_entry->pw_dir) == NULL)
    return (1);
  if (strcat(filename, PATHSEP) == NULL)
    return (1);
  if (strcat(filename, DAHOMED) == NULL)
    return (1);
  if (strcat(filename, PATHSEP) == NULL)
    return (1);
  if (strcat(filename, keyname) == NULL)
    return (1);
  if (strcat(filename, EPASSSUFFIX) == NULL)
    return (1);
  return (0);
}


/* LoadEPassFile() -- takes pointers to epass data and the filename string
as arguments.  Returns 0 on success, 1 on fail. */

int 
LoadEPassFile(dauthr_epass * epass, const char *filename)
{
  FILE *File;


  if (File = fopen(filename, "r")) {
    if (fread(epass, sizeof(*epass), 1, File) != 1)
      return (1);
    if (fclose(File))
      return (1);
    return (0);
  }
  return (1);
}


/* SaveEPassFile() */

int 
SaveEPassFile(dauthr_epass * epass, const char *filename)
{
  FILE *File;

  if (File = fopen(filename, "w")) {
    if (fwrite(epass, sizeof(*epass), 1, File) != 1)
      return (1);
    if (fclose(File))
      return (1);
    return (0);
  }
  return (1);
}


/* LoadKeyFile()  -- takes pointers to the dauthr_key structure and
the pathname.  Returns 0 on success, 1 on fail. */

int 
LoadKeyFile(dauthr_key * dkey, const char *filename)
{
  FILE *File;

  if (File = fopen(filename, "r")) {
    if (fread(dkey, sizeof(*dkey), 1, File) != 1)
      return (1);
    if (fclose(File))
      return (1);
    return (0);
  }
  return (1);
}


/* SaveKeyFile() */

int 
SaveKeyFile(dauthr_key * dkey, const char *filename)
{
  FILE *File;

  if (File = fopen(filename, "w")) {
    if (fwrite(dkey, sizeof(*dkey), 1, File) != 1)
      return (1);
    if (fclose(File))
      return (1);
    return (0);
  }
  return (1);
}
