/* 
 * Copyright 1999-2000, University of Notre Dame.
 * Authors: Jeffrey M. Squyres and Dale Southard
 * 
 * This file is part of the Notre Dame Password Storage and Retrieval
 * (PSR) system.
 * 
 * You should have received a copy of the License Agreement for the Notre
 * Dame PSR system along with the software; see the file LICENSE.  If
 * not, contact Office of Research, University of Notre Dame, Notre Dame,
 * IN 46556.
 * 
 * Permission to modify the code and to distribute modified code is
 * granted, provided the text of this NOTICE is retained, a notice that
 * the code was modified is included with the above COPYRIGHT NOTICE and
 * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
 * file is distributed with the modified code.
 * 
 * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
 * By way of example, but not limitation, Licensor MAKES NO
 * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
 * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
 * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
 * OR OTHER RIGHTS.
 * 
 * Additional copyrights may follow.
 * 
 *
 * $Id: psr.h,v 1.4 2000/11/14 15:41:00 jsquyres Exp $
 *
 * Types and prototypes for PSR routines
 */

#ifndef _psr_h_
#define _psr_h_

/*
 * Get config information info that came from ./configure
 */

#include "psr_config.h"

/* shouldn't need to change anything below */

#ifndef PROTOTYPES
#define PROTOTYPES
#endif

#ifdef _RSAREF_H_
typedef union {
  R_RSA_PRIVATE_KEY rsa_priv_key;
  R_RSA_PUBLIC_KEY rsa_pub_key;
} r_rsa_both_key;

typedef struct {
  char keyname[MAXKEYNAME + 1];
  r_rsa_both_key rsakey;
} dauthr_key;

typedef struct {
  unsigned char iv[8];
  unsigned char encrypted_key[MAX_ENCRYPTED_KEY_LEN];
  unsigned int encrypted_key_length;
  unsigned char encrypted_pass[MAXPASSLENGTH + 7 + 1];
  unsigned int encrypted_pass_length;
} dauthr_epass;

int DecryptPassword(char **, dauthr_epass *, const dauthr_key *);
int EncryptPassword(dauthr_epass *, const char *,
		    const dauthr_key *, R_RANDOM_STRUCT *);
int GenerateKeys(dauthr_key *, dauthr_key *, const char *, R_RANDOM_STRUCT *);
int InitRandomStructure(R_RANDOM_STRUCT *);
void DestroyRandomStructure(R_RANDOM_STRUCT *);
int DefaultEPassFile(char *, const char *, const char *);
int LoadEPassFile(dauthr_epass *, const char *);
int SaveEPassFile(dauthr_epass *, const char *);
int LoadKeyFile(dauthr_key *, const char *);
int SaveKeyFile(dauthr_key *, const char *);

#endif

int Authenticate(char *, char *);
int AuthLife(void);
void GetNewPAG(void);

#endif
